#!/usr/bin/perl -w

# Copyright (c) 2004 by Nicolas FRANÇOIS <nicolas.francois@centraliens.net>
#
# This file is part of po4a.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
########################################################################

=head1 NAME

Locale::Po4a::LaTeX - 

=head1 SEE ALSO

L<po4a(7)|po4a.7>,
L<Locale::Po4a::TransTractor(3pm)|Locale::Po4a::TransTractor>,
L<Locale::Po4a::TeX(3pm)|Locale::Po4a::TeX>.

=head1 AUTHORS

 Nicolas François <nicolas.francois@centraliens.net>

=head1 COPYRIGHT AND LICENSE

Copyright 2004 by Nicolas FRANÇOIS <nicolas.francois@centraliens.net>.

This program is free software; you may redistribute it and/or modify it
under the terms of GPL (see COPYING file).

=cut

package Locale::Po4a::LaTeX;

use 5.006;
use strict;
use warnings;

require Exporter;
use vars qw($VERSION @ISA @EXPORT);
$VERSION=$Locale::Po4a::TeX::VERSION;
@ISA = qw(Locale::Po4a::TeX);
@EXPORT = qw();

#use subs qw(&untranslated);
use Locale::Po4a::TeX;
use vars qw(%commands %environments);
use subs qw(&untranslated &translate_joined &push_environment);
*commands = \%Locale::Po4a::TeX::commands;
*environments = \%Locale::Po4a::TeX::environments;
*untranslated = \&Locale::Po4a::TeX::untranslated;
*translate_joined = \&Locale::Po4a::TeX::translate_joined;
*push_environment = \&Locale::Po4a::TeX::push_environment;
use vars qw($RE_ESCAPE $ESCAPE);
*RE_ESCAPE = \$Locale::Po4a::TeX::RE_ESCAPE;
*ESCAPE    = \$Locale::Po4a::TeX::ESCAPE;
use vars qw($no_wrap_environments $separated_commands);
*no_wrap_environments = \$Locale::Po4a::TeX::no_wrap_environments;
*separated_commands   = \$Locale::Po4a::TeX::separated_commands;
use vars qw(%command_categories);
*command_categories = \%Locale::Po4a::TeX::command_categories;


#documentclass 

$command_categories{'untranslated'} .= " makeindex".
    " myeqnspacing setprotcode font frontmatter chapdir onecolumn".
    " pagebreak sffamily bfseries huge Large ref quad pageref vfill".
    " tableofcontents mainmatter backmatter chaptermark newpage".
    " printindex normalsize normalfont cleardoublepage hline".
    " protect raggedright linebreak hfill Delta qquad appendix junit".
    " sunit";
$commands{'emph'}=\&translate_joined; # see ch01, should not be separated
$command_categories{'translate_joined'} .= " hbox pagenumbering textsf".
    " textbf item textit shoveright";
$environments{'align*'}=
$environments{'align'}=$environments{'center'}=
$environments{'multicols'}=$environments{'equation*'}=
$environments{'description'}=$environments{'flushleft'}=
    \&push_environment;

# temporary:
$command_categories{'untranslated'} .= " boolean pdfprotrudechars".
    " noindent addtocounter setcounter thispagestyle enlargethispage".
    " ldots refstepcounter";
$command_categories{'translate_joined'} .= " ifthenelse".
    " renewcommand include includegraphics input newcommand".
    " addtocontents zu frac text";
$environments{'tabular'}=\&push_environment;
$environments{'tabular*'}=\&push_environment; # TODO: handle *

# newcommands:
$command_categories{'untranslated'} .= " inputprotcode formatchtoc".
    " yesiwantarabic nomarginlayout mynormaltype normallayout parafmt".
    " startoptionalchapters blankchaptermarks brieftitle describeseries".
    " fulltitle spacebetweenfigs startdq egquestion eganswer startdqs".
    " answercheck hwsoln qandaquestion qandaanswer hwendpart".
    " beginscanswers scanshdr beginsolutions hwsolnhdr";
$command_categories{'translate_joined'} .= " titlepagestuff copyrightpage".
    " dedication mychapterwithopener mysection marg fig margdown".
    " vocabitem notationitem widefigsidecaption figureintoc".
    " mychapterwithfullpagewidthopener mychapterwithopenernocaption".
    " mycalcsection myoptionalsection specialchapterwithopener".
    " oneofaseriesofpoints formatlikecaption widefig figureintocnoresize".
    " fullpagewidthfigleft anonymousfig widefiganonymous".
    " fullpagewidthfigrightnocaption widefignocaption anonymousinlinefig".
    " optionalchapternote datatablenote datatablecolhdr formatlikesection".
    " docred cred";
$environments{'titlepages'}=\&push_environment;
$environments{'dq'}=\&push_environment;
$environments{'summary'}=\&push_environment;
$environments{'vocab'}=\&push_environment;
$environments{'notation'}=\&push_environment;
$environments{'othernotation'}=\&push_environment;
$environments{'summarytext'}=\&push_environment;
$environments{'hwsection'}=\&push_environment;
$environments{'numberedequations'}=\&push_environment;
$environments{'minipagefullpagewidth'}=\&push_environment;
$environments{'indentedblock'}=\&push_environment;
$environments{'enumerate'}=\&push_environment;
$environments{'datatablepage'}=\&push_environment;
$environments{'sloppypar'}=\&push_environment;

$environments{'important'}=\&push_environment; # see ch01: {...}[...]
$environments{'lessimportant'}=\&push_environment; # see ch03: {...}[...]
$environments{'eg'}=\&push_environment; # ! should be translatable?
$environments{'hw'}=\&push_environment; # ! should be translatable?
$environments{'selfcheck'}=\&push_environment; # ! should be translatable?
$environments{'optionaltopic'}=\&push_environment; # ! should be translatable?
$environments{'hwcalculus'}=\&push_environment; # ! should be translatable?
$environments{'datatable'}=\&push_environment; # ! should be translatable?

